@@ -35,7 +35,7 @@ class AbstractBox(object):
         if self.y != 0:
             for x in range(self.x, self._get_right()):
                 adj.append(field[self.y - 1][x])
-        return filter(None, adj)
+        return list(filter(None, adj))
 
     # And so on.
     def _adj_bottom(self, field):
@@ -44,14 +44,14 @@ class AbstractBox(object):
         if b != field.height:
             for x in range(self.x, self._get_right()):
                 adj.append(field[b][x])
-        return filter(None, adj)
+        return list(filter(None, adj))
 
     def _adj_left(self, field):
         adj = []
         if self.x != 0:
             for y in range(self.y, self._get_bottom()):
                 adj.append(field[y][self.x - 1])
-        return filter(None, adj)
+        return list(filter(None, adj))
 
     def _adj_right(self, field):
         adj = []
@@ -59,7 +59,7 @@ class AbstractBox(object):
         if r != field.width:
             for y in range(self.y, self._get_bottom()):
                 adj.append(field[y][r])
-        return filter(None, adj)
+        return list(filter(None, adj))
 
     # All blocks adjacent to this one.
     def adjacent(self, field):
@@ -103,7 +103,7 @@ class AbstractBox(object):
     def crash(self, field, gem, immed = False):
         broken = 0
         if not self.crashed and gem.color == self.color:
-            broken += self.size[0] * self.size[1] * (sum(self.size) / 2)
+            broken += self.size[0] * self.size[1] * (sum(self.size) // 2)
             self.crashed = True
             for box in self.adjacent(field):
                 broken += box.crash(field, self)
@@ -134,7 +134,7 @@ class BoxGen(object):
 
 # Find all instances of a given type in a sequence.
 def instances_in(sequence, typ):
-    return filter(lambda x: isinstance(x, typ), sequence)
+    return list(filter(lambda x: isinstance(x, typ), sequence))
 
 class SpriteBox(Sprite):
     def __init__(self, color, type = ""):
