@@ -11,6 +11,8 @@ from pygame.sprite import Sprite, RenderUpdates
 from pygame.color import Color
 from pygame import mixer, transform
 
+from functools import cmp_to_key
+
 from constants import *
 
 import events; from events import Event, EventManager
@@ -60,7 +62,7 @@ class TensionBoner(object):
             rows.append([random.choice(COLORS) for i in range(15)])
             count -= 15
         if count != 0:
-            possible = range(15)
+            possible = list(range(15))
             to_fill = []
             rows.append([random.choice(COLORS) for i in range(15)])
             while count > 0 and len(possible) > 0:
@@ -305,8 +307,8 @@ class BasicField(object):
 
     # Tick all ticking boxes; replace them if their time runs out.
     def tick(self, Box = Box):
-        tickers = filter(lambda b: isinstance(b, TickBox),
-                         util.flatten(self._field))
+        tickers = list(filter(lambda b: isinstance(b, TickBox),
+                         util.flatten(self._field)))
         extickers = []
         for t in tickers:
             t.tick()
@@ -323,12 +325,15 @@ class BasicField(object):
     # give a bonus.
     def tech_bonus(self): pass
 
+    def cmp(self, x, y):
+        return (x > y) - (x < y)
+
     # Try to merge boxes into bigger ones; return True if one
     # merged successfully (only merges one)
     def merge(self):
-        boxes = filter(lambda b: isinstance(b, Box),
-                       util.flatten(self._field))
-        boxes.sort(lambda a, b: cmp(b.y, a.y) and cmp(a.x, b.x))
+        boxes = list(filter(lambda b: isinstance(b, Box),
+                       util.flatten(self._field)))
+        boxes.sort(key=cmp_to_key(lambda a, b: self.cmp(b.y, a.y) and self.cmp(a.x, b.x)))
         for box in boxes:
             dead = box.try_merge(self)
             if len(dead) > 0: return dead
@@ -337,11 +342,11 @@ class BasicField(object):
     # Break everything that will break; return the "value" of
     # the broken 
     def breaking(self):
-        breakers = filter(lambda b: isinstance(b, BreakBox),
-                          util.flatten(self._field))
+        breakers = list(filter(lambda b: isinstance(b, BreakBox),
+                          util.flatten(self._field)))
         killed_count = sum([b.try_crash(self) for b in breakers
                             if not b.crashed])
-        dead = filter(lambda b: b and b.crashed, util.flatten(self._field))
+        dead = list(filter(lambda b: b and b.crashed, util.flatten(self._field)))
         for box in dead: box.remove_from(self)
         return killed_count, dead
 
@@ -724,7 +729,7 @@ class AbstractPlayer(object):
         else: return []
 
     def die(self):
-        print "Player %d is dead!" % (self._pid + 1)
+        print("Player %d is dead!" % (self._pid + 1))
         self.dead = True
 
     def tick(self): pass
@@ -736,7 +741,7 @@ class AbstractPlayer(object):
         self.dead = False
         self._gen = BoxGen(self._rand, self.colors,
                                  isinstance(self, SinglePlayer))
-        self.others = filter(lambda x: x is not self, others)
+        self.others = list(filter(lambda x: x is not self, others))
 
         self.dead_image = pygame.Surface([self.field.width * 32,
                                           self.field.height * 32])
@@ -883,7 +888,7 @@ class AIPlayer(VersusPlayer):
     def update(self, time):
         VersusPlayer.update(self, time)
         if self._iter:
-            move = self._iter.next()
+            move = next(self._iter)
             if move != None:
                 self._iter = None
                 self._goal = move
@@ -993,7 +998,7 @@ class Game(object):
         self._light_axe = self._pickaxe.copy()
         alphs = pygame.surfarray.pixels_alpha(self._light_axe)
         for row in alphs:
-            for i in range(len(row)): row[i] = row[i] / 2
+            for i in range(len(row)): row[i] = row[i] // 2
         del(alphs)
 
     def play(self, matches, wins):
@@ -1002,11 +1007,11 @@ class Game(object):
 
         for i in range(wins[0]):
             screen.blit(self._pickaxe, [225 + 70 * i, 400])
-        for i in range(wins[0], (matches + 1) / 2):
+        for i in range(wins[0], (matches + 1) // 2):
             screen.blit(self._light_axe, [225 + 70 * i, 400])
         for i in range(wins[1]):
             screen.blit(self._pickaxe, [505 - 70 * i, 500])
-        for i in range(wins[1], (matches + 1) / 2):
+        for i in range(wins[1], (matches + 1) // 2):
             screen.blit(self._light_axe, [505 - 70 * i, 500])
         pygame.display.update()
 
@@ -1265,7 +1270,7 @@ class ArcadeGame(Game):
                 else:
                     self.block_out()
 
-                winner = filter(lambda p: not p.dead, self._players)[0]
+                winner = list(filter(lambda p: not p.dead, self._players))[0]
                 winner.win()
                 check_unlock(self._players[0])
                 wins[winner._pid] += 1
@@ -1380,7 +1385,7 @@ def WinScreen(winner, score_sec, to_score = True, scorer = None):
     em = EventManager()
     if scorer is None: scorer = winner
     screen = pygame.display.get_surface()
-    print "Player %d wins!" % (winner._pid + 1)
+    print("Player %d wins!" % (winner._pid + 1))
     wipes.wipe_out()
     wipes.wipe_in(winner.char.images["background"])
     font = textfx.WrapFont(30, 400)
