@@ -5,7 +5,7 @@ __revision__ = "$Id: util.py 286 2004-09-04 03:51:59Z piman $"
 
 import pygame
 
-# Implement the singleton pattern. Requires Python 2.3.
+# Implement the singleton pattern.
 # In reality this didn't work like I thought, because in Python
 # __new__ doesn't call __init__.
 class Singleton(object):
@@ -34,6 +34,6 @@ class WaitClock(object):
 
     def tick(self, fps = 60):
         t = self._time()
-        sleep = (1000 / fps) - (t - self._last_tick)
+        sleep = (1000 // fps) - (t - self._last_tick)
         self._last_tick = t
         if sleep > 0: pygame.time.wait(sleep)
